@@ -1,7 +1,7 @@
 use serde::de::DeserializeOwned;
 use serde_json::Value;
 
-use near_primitives_v01::borsh::BorshDeserialize;
+use near_primitives::borsh::BorshDeserialize;
 
 pub(crate) fn parse_params<T: DeserializeOwned>(
     value: Option<Value>,
@@ -16,11 +16,11 @@ pub(crate) fn parse_params<T: DeserializeOwned>(
 
 pub(crate) fn parse_signed_transaction(
     value: Option<Value>,
-) -> Result<near_primitives_v01::transaction::SignedTransaction, crate::errors::RpcParseError> {
+) -> Result<near_primitives::transaction::SignedTransaction, crate::errors::RpcParseError> {
     let (encoded,) = crate::utils::parse_params::<(String,)>(value.clone())?;
-    let bytes = near_primitives_core_v01::serialize::from_base64(&encoded)
+    let bytes = near_primitives_core::serialize::from_base64(&encoded)
         .map_err(|err| crate::errors::RpcParseError(err.to_string()))?;
-    Ok(near_primitives_v01::transaction::SignedTransaction::try_from_slice(&bytes).map_err(
-        |err| crate::errors::RpcParseError(format!("Failed to decode transaction: {}", err)),
-    )?)
+    Ok(near_primitives::transaction::SignedTransaction::try_from_slice(&bytes).map_err(|err| {
+        crate::errors::RpcParseError(format!("Failed to decode transaction: {}", err))
+    })?)
 }
